@@ -24,6 +24,8 @@ Options:
                                  "from <module> import *" at the top of the file. 
   --incref-local-binop           Force local an extra incref on local variables before
                                  performing any binary operations.
+  --cleanup <level>              Release interned objects on python exit, for memory debugging. 
+                                 Level indicates aggressiveness, default 0 releases nothing. 
   -D, --no-docstrings            Remove docstrings.
   -a, --annotate                 Produce an colorized version of the source.
   --convert-range                Convert for loops using range() function to for...from loops. 
@@ -109,7 +111,7 @@ def parse_command_line(args):
         print >>sys.stderr, \
             "cython: Only one source file allowed when using -o"
         sys.exit(1)
-    if len(sources) == 0:
+    if len(sources) == 0 and not options.show_version:
         bad_usage()
     return options, sources
 
