@@ -797,7 +797,7 @@ class ModuleNode(Nodes.Node, Nodes.BlockNode):
                 code.putln("}")
         for entry in py_attrs:
             name = "p->%s" % entry.cname
-            code.putln("tmp = %s;" % code.as_pyobject(name, entry.type))
+            code.putln("tmp = ((PyObject*)%s);" % name)
             code.put_init_to_py_none(name, entry.type)
             code.putln("Py_XDECREF(tmp);")
         code.putln(
@@ -1207,7 +1207,7 @@ class ModuleNode(Nodes.Node, Nodes.BlockNode):
                 code.putln('{"%s", %s, %s, %s, 0},' % (
                     entry.name,
                     type_code,
-                    "offsetof(%s, %s)" % (objstruct, entry.name),
+                    "offsetof(%s, %s)" % (objstruct, entry.cname),
                     flags))
             code.putln(
                     "{0, 0, 0, 0, 0}")
@@ -1301,6 +1301,7 @@ class ModuleNode(Nodes.Node, Nodes.BlockNode):
             self.generate_builtin_init_code(env, code)
             
         code.putln("%s = PyTuple_New(0); %s" % (Naming.empty_tuple, code.error_goto_if_null(Naming.empty_tuple, self.pos)));
+        code.putln("%s = 0;" % Naming.skip_dispatch_cname);
 
         code.putln("/*--- Global init code ---*/")
         self.generate_global_init_code(env, code)
@@ -1339,10 +1340,12 @@ class ModuleNode(Nodes.Node, Nodes.BlockNode):
         env.use_utility_code(import_module_utility_code)
         env.use_utility_code(register_cleanup_utility_code)
         code.putln()
-        code.putln('static PyObject* cleanup(PyObject *self, PyObject *unused) {')
+        code.putln('static PyObject* %s(PyObject *self, PyObject *unused) {' % Naming.cleanup_cname)
         if Options.generate_cleanup_code >= 2:
             code.putln("/*--- Global cleanup code ---*/")
-            for entry in reversed(env.var_entries):
+            rev_entries = list(env.var_entries)
+            rev_entries.reverse()
+            for entry in rev_entries:
                 if entry.visibility != 'extern':
                     if entry.type.is_pyobject:
                         code.put_var_decref_clear(entry)
@@ -1790,8 +1793,8 @@ bad:
 register_cleanup_utility_code = [
 """
 static int __Pyx_RegisterCleanup(void); /*proto*/
-static PyObject* cleanup(PyObject *self, PyObject *unused); /*proto*/
-static PyMethodDef cleanup_def = {"__cleanup", (PyCFunction)&cleanup, METH_NOARGS, 0};
+static PyObject* __pyx_module_cleanup(PyObject *self, PyObject *unused); /*proto*/
+static PyMethodDef cleanup_def = {"__cleanup", (PyCFunction)&__pyx_module_cleanup, METH_NOARGS, 0};
 ""","""
 static int __Pyx_RegisterCleanup(void) {
     /* Don't use Py_AtExit because that has a 32-call limit 
