@@ -207,12 +207,18 @@ def p_typecast(s):
     s.next()
     base_type = p_c_base_type(s)
     declarator = p_c_declarator(s, empty = 1)
+    if s.sy == '?':
+        s.next()
+        typecheck = 1
+    else:
+        typecheck = 0
     s.expect(">")
     operand = p_factor(s)
     return ExprNodes.TypecastNode(pos, 
         base_type = base_type, 
         declarator = declarator,
-        operand = operand)
+        operand = operand,
+        typecheck = typecheck)
 
 def p_sizeof(s):
     # s.sy == ident "sizeof"
@@ -462,6 +468,10 @@ def p_atom(s):
         s.next()
         if name == "None":
             return ExprNodes.NoneNode(pos)
+        elif name == "True":
+            return ExprNodes.BoolNode(pos, value=1)
+        elif name == "False":
+            return ExprNodes.BoolNode(pos, value=0)
         else:
             return p_name(s, name)
     elif sy == 'NULL':
@@ -1292,7 +1302,7 @@ def p_IF_statement(s, level, cdef_flag, visibility, api):
         if current_eval:
             result = body
     if not result:
-        result = PassStatNode(pos)
+        result = Nodes.PassStatNode(pos)
     s.compile_time_eval = saved_eval
     return result
 
@@ -1319,6 +1329,7 @@ def p_statement(s, level, cdef_flag = 0, visibility = 'private', api = 0):
         if cdef_flag:
             if level not in ('module', 'module_pxd', 'function', 'c_class', 'c_class_pxd'):
                 s.error('cdef statement not allowed here')
+            s.level = level
             return p_cdef_statement(s, level, visibility = visibility,
                                     api = api, overridable = overridable)
     #    elif s.sy == 'cpdef':
@@ -1330,6 +1341,7 @@ def p_statement(s, level, cdef_flag = 0, visibility = 'private', api = 0):
             elif s.sy == 'def':
                 if level not in ('module', 'class', 'c_class', 'property'):
                     s.error('def statement not allowed here')
+                s.level = level
                 return p_def_statement(s)
             elif s.sy == 'class':
                 if level <> 'module':
@@ -1686,7 +1698,13 @@ def p_c_arg_decl(s, in_pyfunc, cmethod_flag = 0, nonempty = 0, kw_only = 0):
         not_none = 1
     if s.sy == '=':
         s.next()
-        default = p_simple_expr(s)
+        if 'pxd' in s.level:
+            if s.sy not in ['*', '?']:
+                error(pos, "default values cannot be specified in pxd files, use ? or *")
+            default = 1
+            s.next()
+        else:
+            default = p_simple_expr(s)
     return Nodes.CArgDeclNode(pos,
         base_type = base_type,
         declarator = declarator,
@@ -1704,8 +1722,6 @@ def p_api(s):
 def p_cdef_statement(s, level, visibility = 'private', api = 0,
                      overridable = False):
     pos = s.position()
-    if overridable and level not in ('c_class', 'c_class_pxd'):
-            error(pos, "Overridable cdef function not allowed here")
     visibility = p_visibility(s, visibility)
     api = api or p_api(s)
     if api:
